\name{annotationPackages}
\alias{annotationPackages}
\title{Annotation Packages}
\description{
  \code{annotationPackages} will return a character vector of the names of annotation packages.
}
\usage{
annotationPackages()
}
\value{
  a character vector of the names of annotation packages
}

