\name{sqsExample}
\alias{sqsExample}
\docType{data}
\title{SnpQSet Example}
\description{
  Example of SnpQSet instance.
}
\usage{data(sqsExample)}
\format{
  Belongs to SnpQSet class.
}
\examples{
data(sqsExample)
class(sqsExample)
}
\keyword{datasets}
