\name{ff_matrix-class}
\Rdversion{1.1}
\docType{class}
\alias{ff_matrix-class}
\alias{annotatedDataFrameFrom,ff_matrix-method}
\title{Class "ff_matrix"}
\description{
  ~~ A concise (1-5 lines) description of what the class is. ~~
}
\section{Objects from the Class}{A virtual Class: No objects may be created from it.}
\section{Slots}{
  \describe{
    \item{\code{.S3Class}:}{Object of class \code{"character"} ~~ }
  }
}
\section{Extends}{
Class \code{"\linkS4class{oldClass}"}, directly.
}
\section{Methods}{
  \describe{
    \item{annotatedDataFrameFrom}{\code{signature(object = "ff_matrix")}: ... }
	 }
}
\examples{
showClass("ff_matrix")
}
\keyword{classes}
