\name{platform-methods}
\docType{methods}
\alias{platform}
\alias{platform-methods}
\alias{platform,FeatureSet-method}
\title{Platform Information}
\description{
  Platform Information
}
\section{Methods}{
\describe{
\item{object = "FeatureSet"}{platform information}
}}
\keyword{methods}
