\name{scqsExample}
\alias{scqsExample}
\docType{data}
\title{SnpCnvQSet Example}
\description{
  Example of SnpCnvQSet object.
}
\usage{data(scqsExample)}
\format{
  Object belongs to SnpCnvQSet class.
}
\examples{
data(scqsExample)
class(scqsExample)
}
\keyword{datasets}
