\name{sfsExample}
\alias{sfsExample}
\docType{data}
\title{SnpFeatureSet Example}
\description{
  Example of SnpFeatureSet object.
}
\usage{data(sfsExample)}
\format{
  Object belongs to SnpFeatureSet class
}
\examples{
data(sfsExample)
class(sfsExample)
}
\keyword{datasets}
