\name{efsExample}
\alias{efsExample}
\docType{data}
\title{ExpressionFeatureSet Object}
\description{
  Example of ExpressionFeatureSet Object.
}
\usage{data(efsExample)}
\format{
  Object belongs to ExpressionFeatureSet class.
}
\examples{
data(efsExample)
class(efsExample)
}
\keyword{datasets}
